/*


             M A K E   B A C K U P S   * N O W * ! ! ! ! ! ! !

Resizing a LineEdit comment base can be risky!  Make backup copies of the
LineEdit DBFs now BEFORE proceeding.  If you do not follow these instructions
absolutely perfectly, you may destroy your only copy of the good comment base
database file.

PROCEDURE FOR RESIZING A COMMENT BASE COMMENT FIELD - USE THIS AS A TEMPLATE
FOR CHANGING OTHER COMMENT BASE STRUCTURES

(Demo code follows this text - change file and field names as necessary)

Step 1: Have your OLD comment base AND New, empty comment base structure
        prepared for use.

        To review: your comment database should be indexed on the
        same index fields as it's "parent" database.  Thus, if the
        main parent database is indexed on "CUST_ACC" then the
        comment database must have the CUST_ACC field as well as
        the field to hold comments (the comment field).  The comment
        base must be indexed on "CUST_ACC+substr(commentfield,1,4)"

        Whatever the main database is indexed on, the comment base must
        be indexed on the same PLUS the first four characters of the
        comment field.

        Have both the old comment base and the new empty comment base
        structure ready for use.


        TO CREATE A NEW EMPTY COMMENT BASE:
        -----------------------------------

        Put the OLD comment base database (the one to be resized) in THIS
        directory (the one where this utility is being run from).  CREATE
        a directory branching from this directory called OUTPUT.

            MD OUTPUT

        Use dbase or similar xBase utility, and COPY THE STRUCTURE OF THE
        OLD comment base to the output directory.

            USE Comments
            COPY STRUCTURE TO OUTPUT\Comments

        You now have your old comment database in the current directory
        and the empty, new, one in the OUTPUT directory.

        Change to the output directory

            CD OUTPUT

        Use your xBase utility, and modify the structure of the NEW comment
        base in the OUTPUT directory.  Change the comment base field to the
        desired length.
        
Step 2: Open BOTH databases in separate areas:

        USE Comments.DBF        ALIAS Source NEW EXCL INDEX Comments.NTX
        USE OUTPUT\Comments.DBF ALIAS Target NEW EXCL INDEX OUTPUT\Comments.NTX

Step 3: For each record in the old database:

        a) _LineEditGet() the old comment
        b) _LineEditPut() the comment into the new comment base.
        c) skip to the next comment in the old comment base.

Step 4: Close files, check results, delete the old comment base,
        and rename the New comment base to the name of the old comment
        base (if desired).


THE FOLLOWING SOURCE CODE
-----------------------------

In the following function, you will need to change the following for each
resize operation, and recompile and run the program:

NOTE A: Change the OLD (INPUT) FILE database name to the name of the comment
        base being resized.

NOTE B: Change the name of the INPUT COMMENT BASE FIELD (This is the one in the
        substr(?????,1,4)  AND the INPUT INDEX NAME.

NOTE C: Change the OUTPUT FILE NAME to either the same name as the input
        or the name you used in the COPY STRU statement above.  Make SURE that
        you specify the OUTPUT\... directory!!!

NOTE D: Change the name of the OUTPUT COMMENT BASE FIELD (This is the one in
        the substr(?????,1,4)  AND the OUTPUT INDEX NAME.  Make SURE that you
        specify the OUTPUT\... directory!!!

NOTE E: Change the name of the SOURCE file index key field.

NOTE F: Change the name of the COMMENT BASE FIELD NAME.

NOTE G: Change the name of the SOURCE FILE INDEX KEY FIELD(S) that are
        used to skip to the next comment record key.  _SKIP2NEXT()
        will skip until the index key field changes, effectively getting
        to the next comment to be processed.

You can safely ignore warnings regarding AMBIGUOUS REFERENCE.  If you wish to
suppress them, add a FIELD statement in the function below, naming each field.
I just ignore them...

Any questions, you may get hold of me in the evenings if you are lucky
on (918) 835-7109. Otherwise, try CIS 70262,524.

*/

FUNCTION main()

LOCAL    i := 0

***********************************************************************

//  NOTE: A
//  OLD FILE       USE THIS ALIAS
//  --------       -------
USE example    ALIAS Source NEW EXCLUSIVE

// NOTE: B
// recreate OLD index                   OLD IDX
//                                      --------
INDEX ON FileName+substr(Example,1,4) TO Example

***********************************************************************

//  NOTE: C
//  NEW FILE                USE THIS ALIAS
//  --------                ------
USE output\Example   ALIAS Target NEW EXCLUSIVE

// NOTE: D
// prepare the new index                          NEW IDX
//                                                --------
INDEX ON FileName+substr(Example,1,4) TO output\Example

ZAP

***********************************************************************

SELECT Source

GOTO TOP

CLEAR SCREEN

while !eof()

    @ 01,00 SAY 'Records Processed:'+str(i++)


    //
    //
    //                   CHANGE THESE FIELD NAMES AS NECESSARY
    //                              |
    //                      |-------------------|
    //                   ---------           --------
    //                   NOTE E:              NOTE F:
    _LineEditPut(Source->FileName, 'TARGET', 'EXAMPLE',;
    _LineEditGet(Source->FileName, 'SOURCE', 'EXAMPLE'))

    // see the _Skip2Next() documentation for explanation
    //
    //           Change this to the OLD index key field name(s)
    //             |
    //          --------
    //           NOTE G:

    _Skip2Next('FileName')

end

RETURN(NIL)

